@@ -11,6 +11,7 @@
 #  --------------------------------------------------------------------------
 
 import argparse
+import copy
 import logging
 import os
 import pprint
@@ -315,7 +316,7 @@ job is either a job number or a job id. Uses current job if not specified."""
         def store_details(job_details):
             # We don't want to store all the outputs in the details themselves, so
             # we make a copy and filter that.
-            filtered_details = job_details.copy()
+            filtered_details = copy.deepcopy(job_details)
             self.lib.filter_large_chunks_from_details(filtered_details)
             filtered_details = pprint.pformat(filtered_details)
             self.save_content(job_id, 'details.json', filtered_details, text=True)
