@@ -25,6 +25,7 @@ import urllib.parse
 from collections import namedtuple
 from contextlib import contextmanager
 from datetime import datetime
+from distutils.version import StrictVersion
 from functools import lru_cache
 from operator import attrgetter
 
@@ -34,6 +35,9 @@ from packaging import version
 
 from ibm_watson_machine_learning import APIClient
 
+# Number of nodes for a deployment
+MAX_NB_NODES = 5
+
 # WML Python API version with a fixed Assets.download function
 WML_HAS_FIXED_DOWNLOAD = "1.0.177"
 # WML Python API version with _asset_id to create a job
@@ -252,7 +256,7 @@ class DOWMLLib:
     space_name = f'{DOWML_PREFIX}-space'
     MODEL_NAME = f'{DOWML_PREFIX}-model'
     MODEL_TYPES = ['cplex', 'cpo', 'opl', 'docplex']
-    DO_VERSION = '20.1'
+    DO_VERSION = '22.1'
     TSHIRT_SIZES = ['S', 'M', 'L', 'XL']
     DEPLOYMENT_NAME = f'{DOWML_PREFIX}-deployment'
 
@@ -338,7 +342,7 @@ class DOWMLLib:
         self.inputs = 'inline' if value else 'assets'
 
     def is_connected_to_onprem(self):
-        return _CredentialsProvider.TOKEN in self._wml_credentials
+        return self._wml_credentials.get("instance_id") == "openshift"
 
     def _create_client(self):
         """Create the Python APIClient instance"""
@@ -757,7 +761,7 @@ class DOWMLLib:
                 self._logger.error(f'Error when trying to delete the Watson Studio run. {r.text}')
                 everything_ok_so_far = False
         if not everything_ok_so_far:
-            if hard:
+            if hard and not self.is_connected_to_onprem():
                 self._logger.error('Could not delete the Watson Studio run. Deleting the WML job deployment instead...')
             # else:
             #   we just wanted to cancel the job, so there's nothing to warn against
@@ -1173,7 +1177,7 @@ class DOWMLLib:
             cdc.NAME: deployment_name,
             cdc.DESCRIPTION: "Deployment for the Solve on WML Python script",
             cdc.BATCH: {},
-            cdc.HARDWARE_SPEC: {'name': self.tshirt_size, 'num_nodes': 2}
+            cdc.HARDWARE_SPEC: {'name': self.tshirt_size, 'num_nodes': MAX_NB_NODES}
         }
         deployment = client.deployments.create(artifact_uid=model_id, meta_props=meta_props)
         self._logger.debug('Deployment created.')
@@ -1213,6 +1217,7 @@ class DOWMLLib:
             match = re.fullmatch(r"do_([0-9.]*)", name)
             if match:
                 available_versions.append(match.group(1))
+        available_versions.sort(key=StrictVersion)
         return available_versions
 
     def _create_model(self, model_name):
